==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Completo</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Vincolo assiale...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>Imposta un vincolo assiale tra due oggetti</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Autotest...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Esegue un autotest per verificare se l'applicazione funziona correttamente</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>D&amp;isegno</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>S&amp;ketch</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>Draf&amp;ting</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Sketch</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Primitive</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Parametrica</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Aspetto dell'oggetto</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Strumenti Wire</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Completo</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Vincolo assiale...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>Imposta un vincolo assiale tra due oggetti</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Autotest...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Esegue un autotest per verificare se l'applicazione funziona correttamente</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>D&amp;isegno</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>S&amp;ketch</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>Draf&amp;ting</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Sketch</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Primitive</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Parametrica</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Aspetto dell'oggetto</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Strumenti Wire</translation>
    </message>
  </context>
</TS>
